-- Copyright (c) 2016-present, Facebook, Inc.
-- All rights reserved.
--
-- This source code is licensed under the BSD-style license found in the
-- LICENSE file in the root directory of this source tree. An additional grant
-- of patent rights can be found in the PATENTS file in the same directory.


{-# LANGUAGE OverloadedStrings #-}

module Duckling.Ordinal.BG.Corpus
  ( corpus
  ) where

import Data.String
import Prelude

import Duckling.Locale
import Duckling.Ordinal.Types
import Duckling.Resolve
import Duckling.Testing.Types

corpus :: Corpus
corpus = (testContext {locale = makeLocale BG Nothing}, testOptions, allExamples)

allExamples :: [Example]
allExamples = concat
  [ examples (OrdinalData 1)
             [ "първи"
             , "първите"
             , "първия"
             , "първият"
             , "първо"
             , "първото"
             , "първа"
             , "първата"
             , "1ви"
             , "1-ви"
             , "1вите"
             , "1-вите"
             , "1вия"
             , "1-вия"
             , "1вият"
             , "1-вият"
             , "1во"
             , "1-во"
             , "1вото"
             , "1-вото"
             , "1ва"
             , "1-ва"
             , "1вата"
             , "1-вата"
             ]
  , examples (OrdinalData 3)
             [ "трети"
             , "третите"
             , "третия"
             , "третият"
             , "трето"
             , "третото"
             , "трета"
             , "третата"
             , "3ти"
             , "3-ти"
             , "3тите"
             , "3-тите"
             , "3тия"
             , "3-тия"
             , "3тият"
             , "3-тият"
             , "3то"
             , "3-то"
             , "3тото"
             , "3-тото"
             , "3та"
             , "3-та"
             , "3тата"
             , "3-тата"
             ]
  , examples (OrdinalData 8)
             [ "осми"
             , "осмите"
             , "осмия"
             , "осмият"
             , "осмо"
             , "осмото"
             , "осма"
             , "осмата"
             , "8ми"
             , "8-ми"
             , "8мите"
             , "8-мите"
             , "8мия"
             , "8-мия"
             , "8мият"
             , "8-мият"
             , "8мо"
             , "8-мо"
             , "8мото"
             , "8-мото"
             , "8ма"
             , "8-ма"
             , "8мата"
             , "8-мата"
             ]
  , examples (OrdinalData 15)
             [ "петнадесети"
             , "петнадесетите"
             , "петнадесетия"
             , "петнадесетият"
             , "петнадесето"
             , "петнадесетото"
             , "петнадесета"
             , "петнадесетата"
             , "15ти"
             , "15-ти"
             , "15тите"
             , "15-тите"
             , "15тия"
             , "15-тия"
             , "15тият"
             , "15-тият"
             , "15то"
             , "15-то"
             , "15тото"
             , "15-тото"
             , "15та"
             , "15-та"
             , "15тата"
             , "15-тата"
             ]
  , examples (OrdinalData 21)
             [ "двадесет и първи"
             , "двадесет и първите"
             , "двадесет и първия"
             , "двадесет и първият"
             , "двадесет и първо"
             , "двадесет и първото"
             , "двадесет и първа"
             , "двадесет и първата"
             , "21ви"
             , "21-ви"
             , "21вите"
             , "21-вите"
             , "21вия"
             , "21-вия"
             , "21вият"
             , "21-вият"
             , "21во"
             , "21-во"
             , "21вото"
             , "21-вото"
             , "21ва"
             , "21-ва"
             , "21вата"
             , "21-вата"
             ]
  , examples (OrdinalData 23)
             [ "двадесет и трети"
             , "двадесет и третите"
             , "двадесет и третия"
             , "двадесет и третият"
             , "двадесет и трето"
             , "двадесет и третото"
             , "двадесет и трета"
             , "двадесет и третата"
             , "23ти"
             , "23-ти"
             , "23тите"
             , "23-тите"
             , "23тия"
             , "23-тия"
             , "23тият"
             , "23-тият"
             , "23то"
             , "23-то"
             , "23тото"
             , "23-тото"
             , "23та"
             , "23-та"
             , "23тата"
             , "23-тата"
             ]
  , examples (OrdinalData 31)
             [ "тридесет и първи"
             , "тридесет и първите"
             , "тридесет и първия"
             , "тридесет и първият"
             , "тридесет и първо"
             , "тридесет и първото"
             , "тридесет и първа"
             , "тридесет и първата"
             , "31ви"
             , "31-ви"
             , "31вите"
             , "31-вите"
             , "31вия"
             , "31-вия"
             , "31вият"
             , "31-вият"
             , "31во"
             , "31-во"
             , "31вото"
             , "31-вото"
             , "31ва"
             , "31-ва"
             , "31вата"
             , "31-вата"
             ]
  , examples (OrdinalData 48)
             [ "четирдесет и осми"
             , "четирдесет и осмите"
             , "четирдесет и осмия"
             , "четирдесет и осмият"
             , "четирдесет и осмо"
             , "четирдесет и осмото"
             , "четирдесет и осма"
             , "четирдесет и осмата"
             , "48ми"
             , "48-ми"
             , "48мите"
             , "48-мите"
             , "48мия"
             , "48-мия"
             , "48мият"
             , "48-мият"
             , "48мо"
             , "48-мо"
             , "48мото"
             , "48-мото"
             , "48ма"
             , "48-ма"
             , "48мата"
             , "48-мата"
             ]
  , examples (OrdinalData 99)
             [ "деветдесет и девети"
             , "деветдесет и деветите"
             , "деветдесет и деветия"
             , "деветдесет и деветият"
             , "деветдесет и девето"
             , "деветдесет и деветото"
             , "деветдесет и девета"
             , "деветдесет и деветата"
             , "99ти"
             , "99-ти"
             , "99тите"
             , "99-тите"
             , "99тия"
             , "99-тия"
             , "99тият"
             , "99-тият"
             , "99то"
             , "99-то"
             , "99тото"
             , "99-тото"
             , "99та"
             , "99-та"
             , "99тата"
             , "99-тата"
             ]
  ]
